Installation — django-richtemplates v0.3.beta documentation

### Navigation

- index
- modules |
- next |
- previous |
- django-richtemplates v0.3.beta documentation »

# Installation

`Richtemplates`, as most Python packages, can be installed in many ways, including:

- Automatic installation using package manager
- Manual installation from source distribution
- Manual installation from Mercurial repository

## Requirements

`django-richtemplates` needs Django 1.2, although it is possible to run it on version 1.1 too [1].

Note

Despite it is not needed, if you intend to contribute on this project, or need to work on it at your fork, we suggest you installing Djalog or simply configure logging module using `logging.basicConfig` method to be able to see logs during development.

## Automatic installation using package manager

Simply run:

    easy_install django-richtemplates

or:

    pip install django-richtemplates

## Manual installation from source distribution

Source archive of the most stable version is available at Python Package Index. Once you’ve downloaded the archive, unpack it, go into newly created directory and type:

    python setup.py install

## Manual installation from Mercurial repository

Package is maintained at bitbucket and if you’d like to you may clone the repository using following command:

    hg clone http://bitbucket.org/lukaszb/django-richtemplates/

Note

You’d need to have Mercurial installed on your system.

After you get clone of the repository, go into `richtemplates` directory and run:

    python setup.py install

Note

You will need superuser privileges in order to install the package.

[1] | You need to provide `django.contrib.messages` for your Django installation and change some templates to work without CSRF security support.

### Navigation

- index
- modules |
- next |
- previous |
- django-richtemplates v0.3.beta documentation »